package fr.cnam.nfa023.heritage;

import java.util.ArrayList;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.view.View;
import fr.cnam.nfa023.heritage.formes.Cercle;
import fr.cnam.nfa023.heritage.formes.Forme;
import fr.cnam.nfa023.heritage.formes.Rectangle;

/**
 * Une surface de dessin.
 * Elle gère une liste de forme, et les redessine quand c'est nécessaire.
 *
 */
public class MyDrawableView extends View {

	/**
	 * La liste des formes.
	 */
	private ArrayList<Forme> formes = new ArrayList<Forme>();
	/**
	 * La "peinture" à utiliser pour les formes :
	 */
	Paint basePaint;
	
	/**
	 * Si une "view" a un constructeur qui prend les arguments context et attrs, 
	 * l'interface d'eclipse peut la proposer dans l'éditeur de layout.
	 * @param context
	 * @param attrs
	 */
	public MyDrawableView(Context context, AttributeSet attrs) {
		super(context, attrs);
		// On initialise la "peinture 
		basePaint= new Paint();
		// on demande l'anticrénelage (voir wikipedia par exemple)
		basePaint.setAntiAlias(true);
		// on fixe la couleur de départ (du gris). 
		// premier argument  : l'opacité.
		basePaint.setColor(Color.argb(255, 200, 200, 200));
		// largeur du trait
		basePaint.setStrokeWidth(3);
		//type de dessin (au trait et non rempli).
		basePaint.setStyle(Paint.Style.STROKE);
	}	
	
	/**
	 * Cette méthode est redéfinie. 
	 * La méthode onDraw est appelée par une View pour se dessiner quand c'est nécessaire. 
	 * @param canvas : la surface de dessin.
	 */
	@Override
	protected void onDraw(Canvas canvas) {
		// On commence par appeler la méthode onDraw de view
		super.onDraw(canvas);
		// On efface la surface de dessin 
		canvas.drawColor(Color.WHITE);
		// on boucle et on demande à chaque forme de se dessiner.
		for (Forme forme : formes) {
			forme.draw(canvas);
		}
	}

	/**
	 * On ajoute une forme choisie au hasard.
	 */
	public void addFormeAleatoire() {
		int i = (int) (Math.random() * 2);
		int x = (int) (Math.random() * getWidth());
		int y = (int) (Math.random() * getHeight());

		// On crée une nouvelle "peinture" à partir de la peinture de base.
		// notez l'utilisation du constructeur de copie de Paint() sur la ligne suivante:
		Paint paint = new Paint(basePaint);
		int r = (int) (Math.random() * 256);
		int g = (int) (Math.random() * 256);
		int b = (int) (Math.random() * 256);
		paint.setColor(Color.argb(255, r, g, b));
		// Selon la valeur de i, on crée un cercle ou un rectangle.
		switch (i) {
		case 0: {
			{
				Rectangle rect = new Rectangle(x, y, x + 100, y + 100, paint);
				formes.add(rect);
			}
			break;
		}
		case 1: {
			Cercle c = new Cercle(x, y, 100, paint);
			formes.add(c);
			break;
		}
		default:
			// pas possible ?
		}
		// on a modifié le dessin, on précise que la "view" n'est plus à jour
		// et qu'elle devra être redessinée.
		invalidate();
	}
}
