package fr.cnam.nfa023.heritage;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

public class PremiereActivity extends Activity {

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		// On associe une action au click sur le bouton :
		activateButton1Version0();
	}

	/**
	 * Première version :  on utilise une classe "normale", Button1Listener
	 * déclarée dans un autre fichier.
	 * 
	 */
	private void activateButton1Version0() {
		Button button = (Button) findViewById(R.id.button1);
		//  Button1Listener a besoin de connaître l'activité d'origine pour créer une 
		// nouvelle activité, et nous nous passons donc comme argument.
		button.setOnClickListener(new Button1Listener(this));
	}

	/**
	 * Seconde version : on utilise une classe interne, Button1ListenerInner comme onclicklistener.
	 * La classe interne a accès aux méthodes et aux variables d'instances de la classe englobante, 
	 * et nous n'avons pas besoin de lui passer "this".
	 * 
	 * Le listener appellera la méthode startExemple1, définie dans PremiereActivity.
	 */
	private void activateButton1Version1() {
		Button button = (Button) findViewById(R.id.button1);
		button.setOnClickListener(new Button1ListenerInner());
	}

	
	/**
	 * Troisième version : on déclare la classe qui implémente le listener à la volée.
	 * C'est une classe <b>anonyme</b>, qui est une classe interne. 
	 * Elle peut appeler directement startExemple1. Notez que ce système n'est viable que 
	 * si le code des classes est très simple.
	 * <p> On ne peut pas écrire de constructeur pour une classe anonyme (ben oui, elle n'a pas de nom...)
	 */
	private void activateButton1Version2() {
		Button button = (Button) findViewById(R.id.button1);
		button.setOnClickListener(new View.OnClickListener() {
			public void onClick(View v) {
				startExemple1();
			}
		});

	}

	protected void startExemple1() {
		Intent intent = new Intent(getApplicationContext(),
				Exemple1Activity.class);
		startActivity(intent);
	}

	/**
	 * Classe interne. Chaque objet de cette classe a accès aux méthodes et variables d'instances de l'objet 
	 * de classe PremiereActivity qui l'a créé.
	 *
	 */
	private class Button1ListenerInner implements OnClickListener {
		public void onClick(View v) {
			// appel direct de startExemple1, qui est une méthode de PremiereActivity.
			startExemple1();
		}
	}

}